#
# File:    ./tests/unit/utils.py
# Author:  Jiří Kučera <sanczes AT gmail.com>
# Date:    2022-07-07 18:20:52 +0200
# Project: vutils-yaml: Working with YAML format
#
# SPDX-License-Identifier: MIT
#
"""
Unit tests utilities.

:const SLOT: The auxiliary slot name
:const VALUE: The auxiliary value
"""

SLOT = "__foo__"
VALUE = "bar:42"
